From 3378b502c5c02de2cc0d9d73bd24aecafa5dd3fe Mon Sep 17 00:00:00 2001
From: Teravus Ovares
Date: Sat, 6 Sep 2008 22:28:51 +0000
Subject: * This changes gridcomms types back to our home grown wholy
controlled types. * These are different types then the OMV types because
changing them causes just about all grid comms to break. If these were the
libOMV types, then libOMV couldn't change them ever again after that.. or
we'd have a breakage whenever they changed them. * This might introduce a map
issue. Still checking it out.
---
.../Region/Communications/OGS1/OGS1GridServices.cs | 6 +++---
.../Region/Communications/OGS1/OGS1InterSimComms.cs | 8 ++++----
.../Region/Communications/OGS1/OGS1UserServices.cs | 20 ++++++++++----------
3 files changed, 17 insertions(+), 17 deletions(-)
(limited to 'OpenSim/Region/Communications')
diff --git a/OpenSim/Region/Communications/OGS1/OGS1InterSimComms.cs b/OpenSim/Region/Communications/OGS1/OGS1InterSimComms.cs
index 1f0c067..0195a58 100644
--- a/OpenSim/Region/Communications/OGS1/OGS1InterSimComms.cs
+++ b/OpenSim/Region/Communications/OGS1/OGS1InterSimComms.cs
@@ -202,13 +202,13 @@ namespace OpenSim.Region.Communications.OGS1
}
- public bool ExpectAvatarCrossing(ulong regionHandle, Guid agentID, Vector3 position, bool isFlying)
+ public bool ExpectAvatarCrossing(ulong regionHandle, Guid agentID, sLLVector3 position, bool isFlying)
{
try
{
return
InterRegionSingleton.Instance.ExpectAvatarCrossing(regionHandle, new UUID(agentID),
- position,
+ new Vector3(position.x, position.y, position.z),
isFlying);
}
catch (RemotingException e)
@@ -218,13 +218,13 @@ namespace OpenSim.Region.Communications.OGS1
}
}
- public bool InformRegionPrim(ulong regionHandle, Guid SceneObjectGroupID, Vector3 position, bool isPhysical)
+ public bool InformRegionPrim(ulong regionHandle, Guid SceneObjectGroupID, sLLVector3 position, bool isPhysical)
{
try
{
return
InterRegionSingleton.Instance.InformRegionPrim(regionHandle, new UUID(SceneObjectGroupID),
- position,
+ new Vector3(position.x, position.y, position.z),
isPhysical);
}
catch (RemotingException e)
diff --git a/OpenSim/Region/Communications/OGS1/OGS1UserServices.cs b/OpenSim/Region/Communications/OGS1/OGS1UserServices.cs
index 317be13..36a82a8 100644
--- a/OpenSim/Region/Communications/OGS1/OGS1UserServices.cs
+++ b/OpenSim/Region/Communications/OGS1/OGS1UserServices.cs
@@ -242,8 +242,8 @@ namespace OpenSim.Region.Communications.OGS1
public void LogOffUser(UUID userid, UUID regionid, ulong regionhandle, float posx, float posy, float posz)
{
Hashtable param = new Hashtable();
- param["avatar_uuid"] = userid.ToString();
- param["region_uuid"] = regionid.ToString();
+ param["avatar_uuid"] = userid.Guid.ToString();
+ param["region_uuid"] = regionid.Guid.ToString();
param["region_handle"] = regionhandle.ToString();
param["region_pos_x"] = posx.ToString();
param["region_pos_y"] = posy.ToString();
@@ -528,8 +528,8 @@ namespace OpenSim.Region.Communications.OGS1
try
{
Hashtable param = new Hashtable();
- param["ownerID"] = friendlistowner.ToString();
- param["friendID"] = friend.ToString();
+ param["ownerID"] = friendlistowner.Guid.ToString();
+ param["friendID"] = friend.Guid.ToString();
param["friendPerms"] = perms.ToString();
IList parameters = new ArrayList();
parameters.Add(param);
@@ -580,8 +580,8 @@ namespace OpenSim.Region.Communications.OGS1
try
{
Hashtable param = new Hashtable();
- param["ownerID"] = friendlistowner.ToString();
- param["friendID"] = friend.ToString();
+ param["ownerID"] = friendlistowner.Guid.ToString();
+ param["friendID"] = friend.Guid.ToString();
IList parameters = new ArrayList();
parameters.Add(param);
@@ -632,8 +632,8 @@ namespace OpenSim.Region.Communications.OGS1
try
{
Hashtable param = new Hashtable();
- param["ownerID"] = friendlistowner.ToString();
- param["friendID"] = friend.ToString();
+ param["ownerID"] = friendlistowner.Guid.ToString();
+ param["friendID"] = friend.Guid.ToString();
param["friendPerms"] = perms.ToString();
IList parameters = new ArrayList();
parameters.Add(param);
@@ -672,7 +672,7 @@ namespace OpenSim.Region.Communications.OGS1
}
}
///
- /// Returns a list of FriendsListItems that describe the friends and permissions in the friend relationship for UUID friendslistowner
+ /// Returns a list of FriendsListItems that describe the friends and permissions in the friend relationship for LLUUID friendslistowner
///
/// The agent that we're retreiving the friends Data.
public List GetUserFriendList(UUID friendlistowner)
@@ -682,7 +682,7 @@ namespace OpenSim.Region.Communications.OGS1
try
{
Hashtable param = new Hashtable();
- param["ownerID"] = friendlistowner.ToString();
+ param["ownerID"] = friendlistowner.Guid.ToString();
IList parameters = new ArrayList();
parameters.Add(param);
diff --git a/OpenSim/Region/Communications/OGS1/OGS1GridServices.cs b/OpenSim/Region/Communications/OGS1/OGS1GridServices.cs
index 1dd4219..a3bcc26 100644
--- a/OpenSim/Region/Communications/OGS1/OGS1GridServices.cs
+++ b/OpenSim/Region/Communications/OGS1/OGS1GridServices.cs
@@ -1212,7 +1212,7 @@ namespace OpenSim.Region.Communications.OGS1
if (remObject != null)
{
retValue =
- remObject.ExpectAvatarCrossing(regionHandle, agentID.Guid, position,
+ remObject.ExpectAvatarCrossing(regionHandle, agentID.Guid, new sLLVector3(position),
isFlying);
}
else
@@ -1269,7 +1269,7 @@ namespace OpenSim.Region.Communications.OGS1
if (remObject != null)
{
retValue =
- remObject.ExpectAvatarCrossing(regionHandle, agentID.Guid, position,
+ remObject.ExpectAvatarCrossing(regionHandle, agentID.Guid, new sLLVector3(position),
isPhysical);
}
else
@@ -1739,7 +1739,7 @@ namespace OpenSim.Region.Communications.OGS1
if (landData != null)
{
// for now, only push out the data we need for answering a ParcelInfoReqeust
// FIXME: these Replace calls are necessary as Vector3.Parse can't parse vectors with spaces in them. Can be removed as soon as we switch to a newer version
hash["AABBMax"] = landData.AABBMax.ToString().Replace(" ", "");
hash["AABBMin"] = landData.AABBMin.ToString().Replace(" ", "");
hash["Area"] = landData.Area.ToString();
@@ -1739,7 +1739,7 @@ namespace OpenSim.Region.Communications.OGS1
{
// for now, only push out the data we need for answering a ParcelInfoReqeust
- // FIXME: these Replace calls are necessary as Vector3.Parse can't parse vectors with spaces in them. Can be removed as soon as we switch to a newer version
+ // FIXME: these Replace calls are necessary as LLVector3.Parse can't parse vectors with spaces in them. Can be removed as soon as we switch to a newer version
hash["AABBMax"] = landData.AABBMax.ToString().Replace(" ", "");
hash["AABBMin"] = landData.AABBMin.ToString().Replace(" ", "");
--
cgit v1.1